安装
===========

使用pip安装
---------------
使用pip安装：

.. code:: bash

    $ pip install cyeva


.. warning:: 

    由于目前项目处于非稳定的beta版本阶段，后续版本更新可能会出现不兼容性修改，因此建议在使用时指定版本号，例如 ``pip install cyeva==0.2.0`` ，可供安装的版本号参考：https://pypi.org/project/cyeva/#history

使用源码安装
---------------

首先在 `版本页面 <https://github.com/caiyunapp/cyeva/releases>`_ 选择想要安装的版本，解压，进入项目目录然后执行：

.. code:: bash

    $ python setup.py install
